# ZSGF.Client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.3
- Generator version: 7.13.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https:////.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https:////.git`)

Then import the package:
```python
import ZSGF.Client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ZSGF.Client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import ZSGF.Client
from ZSGF.Client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api-staging.paomo.fun
# See configuration.py for a list of all supported configuration parameters.
configuration = ZSGF.Client.Configuration(
    host = "https://api-staging.paomo.fun"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: Bearer
configuration = ZSGF.Client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with ZSGF.Client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ZSGF.Client.FileApi(api_client)
    app_key = 'app_key_example' # str | 
    path = 'path_example' # str |  (optional)

    try:
        # 创建文件夹
        api_response = api_instance.file_create_folder(app_key, path=path)
        print("The response of FileApi->file_create_folder:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling FileApi->file_create_folder: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api-staging.paomo.fun*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FileApi* | [**file_create_folder**](docs/FileApi.md#file_create_folder) | **POST** /File/{appKey}/CreateFolder | 创建文件夹
*FileApi* | [**file_delete**](docs/FileApi.md#file_delete) | **DELETE** /File/{appKey} | 删除文件
*FileApi* | [**file_rename**](docs/FileApi.md#file_rename) | **POST** /File/{appKey}/Rename | 重命名文件
*FileApi* | [**file_upload**](docs/FileApi.md#file_upload) | **POST** /File/{appKey}/Upload | 上传文件
*FileApi* | [**files**](docs/FileApi.md#files) | **GET** /File/{appKey} | 文件列表


## Documentation For Models

 - [JObjectApiResult](docs/JObjectApiResult.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="Bearer"></a>
### Bearer

- **Type**: Bearer authentication


## Author




